from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SrcCls:
	"""Src commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("src", core, parent)

	def set(self, source: enums.PayloadLenSource) -> None:
		"""SCPI: CONFigure:WLAN:PAYLoad:LENGth:SRC \n
		Snippet: driver.applications.k91Wlan.configure.wlan.payload.length.src.set(source = enums.PayloadLenSource.ESTimate) \n
		Defines which payload length is used to determine the minimum or maximum number of required data symbols (IEEE 802.11n,
		ac) . \n
			:param source: ESTimate | HTSignal | LSIGnal | SFIeld ESTimate Uses a length estimated from the input signal HTSignal (IEEE811.02 n) Determines the length of the HT signal (from the signal field) LSIGnal (IEEE811.02 ac) Determines the length of the L signal (from the signal field)
		"""
		param = Conversions.enum_scalar_to_str(source, enums.PayloadLenSource)
		self._core.io.write(f'CONFigure:WLAN:PAYLoad:LENGth:SRC {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PayloadLenSource:
		"""SCPI: CONFigure:WLAN:PAYLoad:LENGth:SRC \n
		Snippet: value: enums.PayloadLenSource = driver.applications.k91Wlan.configure.wlan.payload.length.src.get() \n
		Defines which payload length is used to determine the minimum or maximum number of required data symbols (IEEE 802.11n,
		ac) . \n
			:return: source: ESTimate | HTSignal | LSIGnal | SFIeld ESTimate Uses a length estimated from the input signal HTSignal (IEEE811.02 n) Determines the length of the HT signal (from the signal field) LSIGnal (IEEE811.02 ac) Determines the length of the L signal (from the signal field)"""
		response = self._core.io.query_str(f'CONFigure:WLAN:PAYLoad:LENGth:SRC?')
		return Conversions.str_to_scalar_enum(response, enums.PayloadLenSource)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DdpdCls:
	"""Ddpd commands group definition. 15 total commands, 10 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ddpd", core, parent)

	@property
	def window(self):
		"""window commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_window'):
			from .Window import WindowCls
			self._window = WindowCls(self._core, self._cmd_group)
		return self._window

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def apply(self):
		"""apply commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_apply'):
			from .Apply import ApplyCls
			self._apply = ApplyCls(self._core, self._cmd_group)
		return self._apply

	@property
	def count(self):
		"""count commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def rms(self):
		"""rms commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rms'):
			from .Rms import RmsCls
			self._rms = RmsCls(self._core, self._cmd_group)
		return self._rms

	@property
	def finish(self):
		"""finish commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_finish'):
			from .Finish import FinishCls
			self._finish = FinishCls(self._core, self._cmd_group)
		return self._finish

	@property
	def fname(self):
		"""fname commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fname'):
			from .Fname import FnameCls
			self._fname = FnameCls(self._core, self._cmd_group)
		return self._fname

	@property
	def fsave(self):
		"""fsave commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fsave'):
			from .Fsave import FsaveCls
			self._fsave = FsaveCls(self._core, self._cmd_group)
		return self._fsave

	@property
	def gexpansion(self):
		"""gexpansion commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gexpansion'):
			from .Gexpansion import GexpansionCls
			self._gexpansion = GexpansionCls(self._core, self._cmd_group)
		return self._gexpansion

	@property
	def tradeoff(self):
		"""tradeoff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tradeoff'):
			from .Tradeoff import TradeoffCls
			self._tradeoff = TradeoffCls(self._core, self._cmd_group)
		return self._tradeoff

	def continue_py(self) -> None:
		"""SCPI: CONFigure:DDPD:CONTinue \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.continue_py() \n
		Ccontinues direct DPD in manual mode. \n
		"""
		self._core.io.write(f'CONFigure:DDPD:CONTinue')

	def continue_py_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:DDPD:CONTinue \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.continue_py_with_opc() \n
		Ccontinues direct DPD in manual mode. \n
		Same as continue_py, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:DDPD:CONTinue', opc_timeout_ms)

	def abort(self) -> None:
		"""SCPI: CONFigure:DDPD:ABORt \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.abort() \n
		This command stops a DPD sequence and discards the predistorted I/Q data that have been calculated.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on direct DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) .
			- Initiate a DPD sequence (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.start) . \n
		"""
		self._core.io.write(f'CONFigure:DDPD:ABORt')

	def abort_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:DDPD:ABORt \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.abort_with_opc() \n
		This command stops a DPD sequence and discards the predistorted I/Q data that have been calculated.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on direct DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) .
			- Initiate a DPD sequence (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.start) . \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:DDPD:ABORt', opc_timeout_ms)

	def start(self) -> None:
		"""SCPI: CONFigure:DDPD:STARt \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.start() \n
		This command initiates a direct DPD sequence with the number of iterations you have defined. You can define the number of
		iterations with method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.Count.set.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on direct DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
		"""
		self._core.io.write(f'CONFigure:DDPD:STARt')

	def start_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:DDPD:STARt \n
		Snippet: driver.applications.k18AmplifierEt.configure.ddpd.start_with_opc() \n
		This command initiates a direct DPD sequence with the number of iterations you have defined. You can define the number of
		iterations with method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.Count.set.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on direct DPD (method RsFsw.Applications.K18_AmplifierEt.Configure.Ddpd.State.set) . \n
		Same as start, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:DDPD:STARt', opc_timeout_ms)

	def clone(self) -> 'DdpdCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DdpdCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AnnotationCls:
	"""Annotation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("annotation", core, parent)

	def set(self, mode: enums.AnnotationMode) -> None:
		"""SCPI: [SENSe]:FREQuency:ANNotation \n
		Snippet: driver.sense.frequency.annotation.set(mode = enums.AnnotationMode.CSPan) \n
		Switches the labelling of the y-axis for frequency-based result diagrams. The frequency range itself is not changed. This
		function is not available in all applications and measurements. \n
			:param mode: CSPan | SSTop CSPan span / center SSTop start / stop frequency
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AnnotationMode)
		self._core.io.write(f'SENSe:FREQuency:ANNotation {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AnnotationMode:
		"""SCPI: [SENSe]:FREQuency:ANNotation \n
		Snippet: value: enums.AnnotationMode = driver.sense.frequency.annotation.get() \n
		Switches the labelling of the y-axis for frequency-based result diagrams. The frequency range itself is not changed. This
		function is not available in all applications and measurements. \n
			:return: mode: CSPan | SSTop CSPan span / center SSTop start / stop frequency"""
		response = self._core.io.query_str(f'SENSe:FREQuency:ANNotation?')
		return Conversions.str_to_scalar_enum(response, enums.AnnotationMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.TypeLte) -> None:
		"""SCPI: CONFigure[:LTE]:TYPE \n
		Snippet: driver.applications.k10Xlte.configure.lte.typePy.set(type_py = enums.TypeLte.ANCHor) \n
		No command help available \n
			:param type_py: No help available
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.TypeLte)
		self._core.io.write(f'CONFigure:LTE:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.TypeLte:
		"""SCPI: CONFigure[:LTE]:TYPE \n
		Snippet: value: enums.TypeLte = driver.applications.k10Xlte.configure.lte.typePy.get() \n
		No command help available \n
			:return: type_py: No help available"""
		response = self._core.io.query_str(f'CONFigure:LTE:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.TypeLte)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EqualizedCls:
	"""Equalized commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("equalized", core, parent)

	def get(self, input_py: enums.InputRf) -> str:
		"""SCPI: TRACe:IQ:EQUalized \n
		Snippet: value: str = driver.applications.k18AmplifierEt.trace.iq.equalized.get(input_py = enums.InputRf.RF) \n
		This command queries the equalized I/Q data.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Equalized data must be available. \n
			:param input_py: RF You have to state this parameter, but it is always 'RF'.
			:return: result: String containing the I/Q data."""
		param = Conversions.enum_scalar_to_str(input_py, enums.InputRf)
		response = self._core.io.query_str(f'TRACe:IQ:EQUalized? {param}')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BdSourceCls:
	"""BdSource commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bdSource", core, parent)

	def set(self, reference: enums.ReferenceBdSourceK10x) -> None:
		"""SCPI: CONFigure[:LTE]:UL:BDSource \n
		Snippet: driver.applications.k10Xlte.configure.lte.uplink.bdSource.set(reference = enums.ReferenceBdSourceK10x.NONE) \n
		No command help available \n
			:param reference: No help available
		"""
		param = Conversions.enum_scalar_to_str(reference, enums.ReferenceBdSourceK10x)
		self._core.io.write(f'CONFigure:LTE:UL:BDSource {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ReferenceBdSourceK10x:
		"""SCPI: CONFigure[:LTE]:UL:BDSource \n
		Snippet: value: enums.ReferenceBdSourceK10x = driver.applications.k10Xlte.configure.lte.uplink.bdSource.get() \n
		No command help available \n
			:return: reference: No help available"""
		response = self._core.io.query_str(f'CONFigure:LTE:UL:BDSource?')
		return Conversions.str_to_scalar_enum(response, enums.ReferenceBdSourceK10x)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CrateCls:
	"""Crate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("crate", core, parent)

	def set(self, chip_rate: float) -> None:
		"""SCPI: CONFigure:EDMG:CRATe \n
		Snippet: driver.applications.k9X11Ad.configure.edmg.crate.set(chip_rate = 1.0) \n
		Chip rate used for transmission; specified in the IEEE 802.11 ay standard as: NCB * 1.76 GHz \n
			:param chip_rate: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(chip_rate)
		self._core.io.write(f'CONFigure:EDMG:CRATe {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:EDMG:CRATe \n
		Snippet: value: float = driver.applications.k9X11Ad.configure.edmg.crate.get() \n
		Chip rate used for transmission; specified in the IEEE 802.11 ay standard as: NCB * 1.76 GHz \n
			:return: chip_rate: Unit: HZ"""
		response = self._core.io.query_str(f'CONFigure:EDMG:CRATe?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CdataCls:
	"""Cdata commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cdata", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: MMEMory:SELect[:ITEM]:CDATa \n
		Snippet: driver.massMemory.select.item.cdata.set(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'MMEMory:SELect:ITEM:CDATa {param}')

	def get(self) -> bool:
		"""SCPI: MMEMory:SELect[:ITEM]:CDATa \n
		Snippet: value: bool = driver.massMemory.select.item.cdata.get() \n
		No command help available \n
			:return: state: No help available"""
		response = self._core.io.query_str(f'MMEMory:SELect:ITEM:CDATa?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HopDetectionCls:
	"""HopDetection commands group definition. 77 total commands, 14 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hopDetection", core, parent)

	@property
	def compensation(self):
		"""compensation commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_compensation'):
			from .Compensation import CompensationCls
			self._compensation = CompensationCls(self._core, self._cmd_group)
		return self._compensation

	@property
	def pcoherent(self):
		"""pcoherent commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pcoherent'):
			from .Pcoherent import PcoherentCls
			self._pcoherent = PcoherentCls(self._core, self._cmd_group)
		return self._pcoherent

	@property
	def fmTolerance(self):
		"""fmTolerance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fmTolerance'):
			from .FmTolerance import FmToleranceCls
			self._fmTolerance = FmToleranceCls(self._core, self._cmd_group)
		return self._fmTolerance

	@property
	def pmTolerance(self):
		"""pmTolerance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmTolerance'):
			from .PmTolerance import PmToleranceCls
			self._pmTolerance = PmToleranceCls(self._core, self._cmd_group)
		return self._pmTolerance

	@property
	def frequency(self):
		"""frequency commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def fdeviation(self):
		"""fdeviation commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_fdeviation'):
			from .Fdeviation import FdeviationCls
			self._fdeviation = FdeviationCls(self._core, self._cmd_group)
		return self._fdeviation

	@property
	def pdeviation(self):
		"""pdeviation commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdeviation'):
			from .Pdeviation import PdeviationCls
			self._pdeviation = PdeviationCls(self._core, self._cmd_group)
		return self._pdeviation

	@property
	def total(self):
		"""total commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_total'):
			from .Total import TotalCls
			self._total = TotalCls(self._core, self._cmd_group)
		return self._total

	@property
	def pnoise(self):
		"""pnoise commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_pnoise'):
			from .Pnoise import PnoiseCls
			self._pnoise = PnoiseCls(self._core, self._cmd_group)
		return self._pnoise

	@property
	def power(self):
		"""power commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def dwell(self):
		"""dwell commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_dwell'):
			from .Dwell import DwellCls
			self._dwell = DwellCls(self._core, self._cmd_group)
		return self._dwell

	@property
	def states(self):
		"""states commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_states'):
			from .States import StatesCls
			self._states = StatesCls(self._core, self._cmd_group)
		return self._states

	@property
	def selected(self):
		"""selected commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_selected'):
			from .Selected import SelectedCls
			self._selected = SelectedCls(self._core, self._cmd_group)
		return self._selected

	@property
	def table(self):
		"""table commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_table'):
			from .Table import TableCls
			self._table = TableCls(self._core, self._cmd_group)
		return self._table

	def clone(self) -> 'HopDetectionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HopDetectionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def get(self, window=repcap.Window.Default) -> str:
		"""SCPI: CALCulate<n>:DISTribution:Y \n
		Snippet: value: str = driver.applications.k60Transient.calculate.distribution.y.get(window = repcap.Window.Default) \n
		Queries the y-axis values of the specified Parameter Distribution display. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: yaxis: char_data The number of values is defined by method RsFsw.Applications.K6_Pulse.Calculate.Distribution.Nbins.set. The used unit depends on the selected parameter."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DISTribution:Y?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class K91_WlanCls:
	"""K91_Wlan commands group definition. 529 total commands, 16 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("k91_Wlan", core, parent)

	@property
	def layout(self):
		"""layout commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_layout'):
			from .Layout import LayoutCls
			self._layout = LayoutCls(self._core, self._cmd_group)
		return self._layout

	@property
	def massMemory(self):
		"""massMemory commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_massMemory'):
			from .MassMemory import MassMemoryCls
			self._massMemory = MassMemoryCls(self._core, self._cmd_group)
		return self._massMemory

	@property
	def trace(self):
		"""trace commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def configure(self):
		"""configure commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_configure'):
			from .Configure import ConfigureCls
			self._configure = ConfigureCls(self._core, self._cmd_group)
		return self._configure

	@property
	def calculate(self):
		"""calculate commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_calculate'):
			from .Calculate import CalculateCls
			self._calculate = CalculateCls(self._core, self._cmd_group)
		return self._calculate

	@property
	def fetch(self):
		"""fetch commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_fetch'):
			from .Fetch import FetchCls
			self._fetch = FetchCls(self._core, self._cmd_group)
		return self._fetch

	@property
	def sense(self):
		"""sense commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_sense'):
			from .Sense import SenseCls
			self._sense = SenseCls(self._core, self._cmd_group)
		return self._sense

	@property
	def calibration(self):
		"""calibration commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_calibration'):
			from .Calibration import CalibrationCls
			self._calibration = CalibrationCls(self._core, self._cmd_group)
		return self._calibration

	@property
	def display(self):
		"""display commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_display'):
			from .Display import DisplayCls
			self._display = DisplayCls(self._core, self._cmd_group)
		return self._display

	@property
	def formatPy(self):
		"""formatPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	@property
	def initiate(self):
		"""initiate commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_initiate'):
			from .Initiate import InitiateCls
			self._initiate = InitiateCls(self._core, self._cmd_group)
		return self._initiate

	@property
	def inputPy(self):
		"""inputPy commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def output(self):
		"""output commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_output'):
			from .Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def trigger(self):
		"""trigger commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def triggerInvoke(self):
		"""triggerInvoke commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_triggerInvoke'):
			from .TriggerInvoke import TriggerInvokeCls
			self._triggerInvoke = TriggerInvokeCls(self._core, self._cmd_group)
		return self._triggerInvoke

	@property
	def unit(self):
		"""unit commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_unit'):
			from .Unit import UnitCls
			self._unit = UnitCls(self._core, self._cmd_group)
		return self._unit

	def abort(self) -> None:
		"""SCPI: ABORt \n
		Snippet: driver.applications.k91_Wlan.abort() \n
		This command aborts the measurement in the current channel and resets the trigger system. To prevent overlapping
		execution of the subsequent command before the measurement has been aborted successfully, use the *OPC? or *WAI command
		after method RsFsw.#Abort CMDLINKRESOLVED] and before the next command. For details on overlapping execution see Remote
		control via SCPI. To abort a sequence of measurements by the Sequencer, use the [CMDLINKRESOLVED Initiate.Sequencer.abort
		command. Note on blocked remote control programs: If a sequential command cannot be completed, for example because a
		triggered sweep never receives a trigger, the remote control program will never finish and the remote channel to the R&S
		FSW is blocked for further commands. In this case, you must interrupt processing on the remote channel first in order to
		abort the measurement. To do so, send a 'Device Clear' command from the control instrument to the R&S FSW on a parallel
		channel to clear all currently active remote channels. Depending on the used interface and protocol, send the following
		commands:
			INTRO_CMD_HELP: The .csv file has the following structure: \n
			- Visa: viClear
			- GPIB: ibclr
			- RSIB: RSDLLibclr
		Now you can send the [CMDLINKRESOLVED #Abort CMDLINKRESOLVED] command on the remote channel performing the measurement. \n
		"""
		self._core.io.write(f'ABORt')

	def abort_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ABORt \n
		Snippet: driver.applications.k91_Wlan.abort_with_opc() \n
		This command aborts the measurement in the current channel and resets the trigger system. To prevent overlapping
		execution of the subsequent command before the measurement has been aborted successfully, use the *OPC? or *WAI command
		after method RsFsw.#Abort CMDLINKRESOLVED] and before the next command. For details on overlapping execution see Remote
		control via SCPI. To abort a sequence of measurements by the Sequencer, use the [CMDLINKRESOLVED Initiate.Sequencer.abort
		command. Note on blocked remote control programs: If a sequential command cannot be completed, for example because a
		triggered sweep never receives a trigger, the remote control program will never finish and the remote channel to the R&S
		FSW is blocked for further commands. In this case, you must interrupt processing on the remote channel first in order to
		abort the measurement. To do so, send a 'Device Clear' command from the control instrument to the R&S FSW on a parallel
		channel to clear all currently active remote channels. Depending on the used interface and protocol, send the following
		commands:
			INTRO_CMD_HELP: The .csv file has the following structure: \n
			- Visa: viClear
			- GPIB: ibclr
			- RSIB: RSDLLibclr
		Now you can send the [CMDLINKRESOLVED #Abort CMDLINKRESOLVED] command on the remote channel performing the measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ABORt', opc_timeout_ms)

	def clone(self) -> 'K91_WlanCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = K91_WlanCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConnectorCls:
	"""Connector commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("connector", core, parent)

	def set(self, conn_type: enums.InputConnector) -> None:
		"""SCPI: INPut:CONNector \n
		Snippet: driver.applications.k14Xnr5G.inputPy.connector.set(conn_type = enums.InputConnector.AIQI) \n
		Determines which connector the input for the measurement is taken from. For more information, see 'Receiving Data Input
		and Providing Data Output'. If an external frontend is active, the connector is automatically set to RF. \n
			:param conn_type: RF RF input connector RFPRobe Active RF probe
		"""
		param = Conversions.enum_scalar_to_str(conn_type, enums.InputConnector)
		self._core.io.write(f'INPut:CONNector {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.InputConnector:
		"""SCPI: INPut:CONNector \n
		Snippet: value: enums.InputConnector = driver.applications.k14Xnr5G.inputPy.connector.get() \n
		Determines which connector the input for the measurement is taken from. For more information, see 'Receiving Data Input
		and Providing Data Output'. If an external frontend is active, the connector is automatically set to RF. \n
			:return: conn_type: RF RF input connector RFPRobe Active RF probe"""
		response = self._core.io.query_str(f'INPut:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.InputConnector)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, format_py: enums.PucchFormat, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default) -> None:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:SUBFrame<sf>:ALLoc:PUCCh:FORMat \n
		Snippet: driver.applications.k10Xlte.configure.lte.uplink.cc.subframe.alloc.pucch.formatPy.set(format_py = enums.PucchFormat.F1, carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default) \n
		This command selects the PUCCH format for a specific subframe. The command is available if you have selected PUCCH format
		selection on subframe basis with method RsFsw.Applications.K10x_Lte.Configure.Lte.Uplink.Cc.Pucch.FormatPy.set. \n
			:param format_py: F1 (F1) F1A (F1a) F1B (F1b) F2 (F2) F2A (F2a) F2B (F2b) F3 (F3)
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.PucchFormat)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		self._core.io.write(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:SUBFrame{subframe_cmd_val}:ALLoc:PUCCh:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default) -> enums.PucchFormat:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:SUBFrame<sf>:ALLoc:PUCCh:FORMat \n
		Snippet: value: enums.PucchFormat = driver.applications.k10Xlte.configure.lte.uplink.cc.subframe.alloc.pucch.formatPy.get(carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default) \n
		This command selects the PUCCH format for a specific subframe. The command is available if you have selected PUCCH format
		selection on subframe basis with method RsFsw.Applications.K10x_Lte.Configure.Lte.Uplink.Cc.Pucch.FormatPy.set. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
			:return: format_py: F1 (F1) F1A (F1a) F1B (F1b) F2 (F2) F2A (F2a) F2B (F2b) F3 (F3)"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		response = self._core.io.query_str(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:SUBFrame{subframe_cmd_val}:ALLoc:PUCCh:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.PucchFormat)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GeneratorCls:
	"""Generator commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("generator", core, parent)

	def set(self, frequency: float) -> None:
		"""SCPI: CONFigure:GENerator:MCGD:AFTM:FREQuency:GENerator \n
		Snippet: driver.applications.k17Mcgd.configure.generator.mcgd.aftm.frequency.generator.set(frequency = 1.0) \n
		Determines the signal generator frequency. Any changes here are automatically applied to the connected generator. \n
			:param frequency: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'CONFigure:GENerator:MCGD:AFTM:FREQuency:GENerator {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:GENerator:MCGD:AFTM:FREQuency:GENerator \n
		Snippet: value: float = driver.applications.k17Mcgd.configure.generator.mcgd.aftm.frequency.generator.get() \n
		Determines the signal generator frequency. Any changes here are automatically applied to the connected generator. \n
			:return: frequency: Unit: HZ"""
		response = self._core.io.query_str(f'CONFigure:GENerator:MCGD:AFTM:FREQuency:GENerator?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaxCls:
	"""Max commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("max", core, parent)

	def set(self, num_data_symbols: float) -> None:
		"""SCPI: [SENSe]:DEMod:FORMat:BANalyze:SYMBols:MAX \n
		Snippet: driver.applications.k91Wlan.sense.demod.formatPy.banalyze.symbols.max.set(num_data_symbols = 1.0) \n
		For IEEE 802.11a, ac, g (OFDM) , j, n, p signals only: If the [SENSe:]DEMod:FORMat:BANalyze:SYMBols:EQUal command is set
		to false, this command specifies the maximum number of payload symbols allowed for a PPDU to take part in measurement
		analysis. The number of payload symbols is defined as the uncoded bits including service and tail bits.
		If the [SENSe:]DEMod:FORMat:BANalyze:SYMBols:EQUal command has been set to true, then this command has no effect. \n
			:param num_data_symbols: integer
		"""
		param = Conversions.decimal_value_to_str(num_data_symbols)
		self._core.io.write(f'SENSe:DEMod:FORMat:BANalyze:SYMBols:MAX {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DEMod:FORMat:BANalyze:SYMBols:MAX \n
		Snippet: value: float = driver.applications.k91Wlan.sense.demod.formatPy.banalyze.symbols.max.get() \n
		For IEEE 802.11a, ac, g (OFDM) , j, n, p signals only: If the [SENSe:]DEMod:FORMat:BANalyze:SYMBols:EQUal command is set
		to false, this command specifies the maximum number of payload symbols allowed for a PPDU to take part in measurement
		analysis. The number of payload symbols is defined as the uncoded bits including service and tail bits.
		If the [SENSe:]DEMod:FORMat:BANalyze:SYMBols:EQUal command has been set to true, then this command has no effect. \n
			:return: num_data_symbols: integer"""
		response = self._core.io.query_str(f'SENSe:DEMod:FORMat:BANalyze:SYMBols:MAX?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPyCls:
	"""FilterPy commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("filterPy", core, parent)

	@property
	def coefficient(self):
		"""coefficient commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coefficient'):
			from .Coefficient import CoefficientCls
			self._coefficient = CoefficientCls(self._core, self._cmd_group)
		return self._coefficient

	def clone(self) -> 'FilterPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, op_mode: enums.InstrumentMode) -> None:
		"""SCPI: INSTrument:MODE \n
		Snippet: driver.instrument.mode.set(op_mode = enums.InstrumentMode.MSRanalyzer) \n
		The operating mode of the R&S FSW determines which applications are available and active. Whenever you change the
		operating mode, the currently active channels are closed. The default operating mode is Signal and Spectrum Analyzer mode,
		however, the presetting can be changed. (See 'Preset Mode') . For details on operating modes and applications see
		'Applications, measurement channels, and operating modes'. \n
			:param op_mode: SANalyzer Signal and Spectrum Analyzer mode MSRanalyzer Multi-Standard Radio Analysis (MSRA) mode RTMStandard Multi-Standard Real-Time (MSRT) mode Only available if one of the real-time options is installed. (See 'Welcome to the R&S FSW Real-Time Extension') .
		"""
		param = Conversions.enum_scalar_to_str(op_mode, enums.InstrumentMode)
		self._core.io.write_with_opc(f'INSTrument:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.InstrumentMode:
		"""SCPI: INSTrument:MODE \n
		Snippet: value: enums.InstrumentMode = driver.instrument.mode.get() \n
		The operating mode of the R&S FSW determines which applications are available and active. Whenever you change the
		operating mode, the currently active channels are closed. The default operating mode is Signal and Spectrum Analyzer mode,
		however, the presetting can be changed. (See 'Preset Mode') . For details on operating modes and applications see
		'Applications, measurement channels, and operating modes'. \n
			:return: op_mode: SANalyzer Signal and Spectrum Analyzer mode MSRanalyzer Multi-Standard Radio Analysis (MSRA) mode RTMStandard Multi-Standard Real-Time (MSRT) mode Only available if one of the real-time options is installed. (See 'Welcome to the R&S FSW Real-Time Extension') ."""
		response = self._core.io.query_str_with_opc(f'INSTrument:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.InstrumentMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StandardCls:
	"""Standard commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("standard", core, parent)

	def set(self, standard: enums.SelectNone, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:PRESet[:STANdard] \n
		Snippet: driver.applications.k14Xnr5G.sense.espectrum.preset.standard.set(standard = enums.SelectNone.NONE, subBlock = repcap.SubBlock.Default) \n
		This command loads an SEM settings file for combined measurements. \n
			:param standard: (enum or string) string String that contains the path to the settings file (.xml format) . NONE Removes the settings file.
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		param = Conversions.enum_ext_scalar_to_str(standard, enums.SelectNone)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:PRESet:STANdard {param}')

	# noinspection PyTypeChecker
	def get(self, subBlock=repcap.SubBlock.Default) -> enums.SelectNone:
		"""SCPI: [SENSe]:ESPectrum<sb>:PRESet[:STANdard] \n
		Snippet: value: enums.SelectNone = driver.applications.k14Xnr5G.sense.espectrum.preset.standard.get(subBlock = repcap.SubBlock.Default) \n
		This command loads an SEM settings file for combined measurements. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:return: standard: (enum or string) string String that contains the path to the settings file (.xml format) . NONE Removes the settings file."""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:PRESet:STANdard?')
		return Conversions.str_to_scalar_enum_ext(response, enums.SelectNone)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, power: float, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ESPectrum<sb>:VALue \n
		Snippet: driver.calculate.limit.espectrum.value.set(power = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, subBlock = repcap.SubBlock.Default) \n
		This command activates the manual limit line selection as and specifies the expected power as a value. Depending on the
		entered value, the associated predefined limit lines is selected. This command has the same effect as a combination of
		the CALC:LIM:ESP:MODE MAN and the method RsFsw.Calculate.Limit.Espectrum.Pclass.Exclusive.set commands; however, the
		power class to be used is not defined directly, but via the expected power. As opposed to CALC:LIM:ESP:MODE AUTO, the
		power class is not re-assigned to the input signal power dynamically, but only once when the command is executed. \n
			:param power: integer Range: -200 to 199
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		param = Conversions.decimal_value_to_str(power)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ESPectrum{subBlock_cmd_val}:VALue {param}')

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, subBlock=repcap.SubBlock.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit<li>:ESPectrum<sb>:VALue \n
		Snippet: value: float = driver.calculate.limit.espectrum.value.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, subBlock = repcap.SubBlock.Default) \n
		This command activates the manual limit line selection as and specifies the expected power as a value. Depending on the
		entered value, the associated predefined limit lines is selected. This command has the same effect as a combination of
		the CALC:LIM:ESP:MODE MAN and the method RsFsw.Calculate.Limit.Espectrum.Pclass.Exclusive.set commands; however, the
		power class to be used is not defined directly, but via the expected power. As opposed to CALC:LIM:ESP:MODE AUTO, the
		power class is not re-assigned to the input signal power dynamically, but only once when the command is executed. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:return: power: integer Range: -200 to 199"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ESPectrum{subBlock_cmd_val}:VALue?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get(self) -> int:
		"""SCPI: [SENSe]:EVALuation:PACKet:COUNt \n
		Snippet: value: int = driver.applications.k149Uwb.sense.evaluation.packet.count.get() \n
		Returns the number of packets analyzed. \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'SENSe:EVALuation:PACKet:COUNt?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DfRangeCls:
	"""DfRange commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dfRange", core, parent)

	def set(self, deployment: enums.DeploymentFrange, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:DFRange \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.dfRange.set(deployment = enums.DeploymentFrange.EHIGh, carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the deployment frequency range of the signal. \n
			:param deployment: LOW Deployment in FR1 ≤ 3 GHz. MIDDle Deployment in FR1 3 GHz. HIGH Deployment in FR2-1. EHIGh Deployment in FR2-2.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.enum_scalar_to_str(deployment, enums.DeploymentFrange)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:DFRange {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.DeploymentFrange:
		"""SCPI: CONFigure[:NR5G]:DL[:CC<cc>]:DFRange \n
		Snippet: value: enums.DeploymentFrange = driver.applications.k14Xnr5G.configure.nr5G.downlink.cc.dfRange.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the deployment frequency range of the signal. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: deployment: LOW Deployment in FR1 ≤ 3 GHz. MIDDle Deployment in FR1 3 GHz. HIGH Deployment in FR2-1. EHIGh Deployment in FR2-2."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:CC{carrierComponent_cmd_val}:DFRange?')
		return Conversions.str_to_scalar_enum(response, enums.DeploymentFrange)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VdeviceCls:
	"""Vdevice commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("vdevice", core, parent)

	def get(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:VDEVice \n
		Snippet: value: bool = driver.applications.k70Vsa.system.communicate.rdevice.oscilloscope.vdevice.get() \n
		Queries whether the connected instrument is supported by the 2 GHz / 5 GHz bandwidth extension option(B2000/B5000) . For
		details see 'Prerequisites and Measurement Setup'. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:VDEVice?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:POWer:SEM:CHBS:AMPower:AUTO \n
		Snippet: driver.applications.k10Xlte.sense.power.sem.chbs.amPower.auto.set(state = False) \n
		This command turn automatic detection of the TX channel power on and off.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select medium range base stations ([SENSe:]POWer:SEM:CATegory) .
		When you turn off automatic detection, you can define the TX channel power manually with [SENSe:]POWer:SEM:CHBS:AMPower. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:POWer:SEM:CHBS:AMPower:AUTO {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:POWer:SEM:CHBS:AMPower:AUTO \n
		Snippet: value: bool = driver.applications.k10Xlte.sense.power.sem.chbs.amPower.auto.get() \n
		This command turn automatic detection of the TX channel power on and off.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select medium range base stations ([SENSe:]POWer:SEM:CATegory) .
		When you turn off automatic detection, you can define the TX channel power manually with [SENSe:]POWer:SEM:CHBS:AMPower. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'SENSe:POWer:SEM:CHBS:AMPower:AUTO?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BanalyzeCls:
	"""Banalyze commands group definition. 15 total commands, 4 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("banalyze", core, parent)

	@property
	def btype(self):
		"""btype commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_btype'):
			from .Btype import BtypeCls
			self._btype = BtypeCls(self._core, self._cmd_group)
		return self._btype

	@property
	def symbols(self):
		"""symbols commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_symbols'):
			from .Symbols import SymbolsCls
			self._symbols = SymbolsCls(self._core, self._cmd_group)
		return self._symbols

	@property
	def dbytes(self):
		"""dbytes commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_dbytes'):
			from .Dbytes import DbytesCls
			self._dbytes = DbytesCls(self._core, self._cmd_group)
		return self._dbytes

	@property
	def duration(self):
		"""duration commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import DurationCls
			self._duration = DurationCls(self._core, self._cmd_group)
		return self._duration

	def set(self, format_py: str) -> None:
		"""SCPI: [SENSe]:DEMod:FORMat:BANalyze \n
		Snippet: driver.applications.k91Wlan.sense.demod.formatPy.banalyze.set(format_py = '1') \n
		Specifies which PSDUs are to be analyzed depending on their modulation. Only PSDUs using the selected modulation are
		considered in result analysis. Note: to analyze all PPDUs that are identical to the first detected PPDU (corresponds to
		'Auto, same type as first PPDU') , use the command: SENS:DEMO:FORM:BANA:BTYP:AUTO:TYPE FBUR. To analyze all PPDUs
		regardless of their format and modulation (corresponds to 'Auto, individually for each PPDU') , use the command:
		SENS:DEMO:FORM:BANA:BTYP:AUTO:TYPE ALL. To analyze all PPDUs using the same modulation (corresponds to 'Demod all as...',
		use the command: SENS:DEMO:FORM:BANA:BTYP:AUTO:TYPE ... See [SENSe:]DEMod:FORMat:BANalyze:BTYPe:AUTO:TYPE. \n
			:param format_py: No help available
		"""
		param = Conversions.value_to_quoted_str(format_py)
		self._core.io.write(f'SENSe:DEMod:FORMat:BANalyze {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DEMod:FORMat:BANalyze \n
		Snippet: value: str = driver.applications.k91Wlan.sense.demod.formatPy.banalyze.get() \n
		Specifies which PSDUs are to be analyzed depending on their modulation. Only PSDUs using the selected modulation are
		considered in result analysis. Note: to analyze all PPDUs that are identical to the first detected PPDU (corresponds to
		'Auto, same type as first PPDU') , use the command: SENS:DEMO:FORM:BANA:BTYP:AUTO:TYPE FBUR. To analyze all PPDUs
		regardless of their format and modulation (corresponds to 'Auto, individually for each PPDU') , use the command:
		SENS:DEMO:FORM:BANA:BTYP:AUTO:TYPE ALL. To analyze all PPDUs using the same modulation (corresponds to 'Demod all as...',
		use the command: SENS:DEMO:FORM:BANA:BTYP:AUTO:TYPE ... See [SENSe:]DEMod:FORMat:BANalyze:BTYPe:AUTO:TYPE. \n
			:return: format_py: No help available"""
		response = self._core.io.query_str(f'SENSe:DEMod:FORMat:BANalyze?')
		return trim_str_response(response)

	def clone(self) -> 'BanalyzeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BanalyzeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CdeviceCls:
	"""Cdevice commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cdevice", core, parent)

	def get(self) -> str:
		"""SCPI: INPut:DIQ:CDEVice \n
		Snippet: value: str = driver.applications.k6Pulse.inputPy.diq.cdevice.get() \n
		This command queries the current configuration and the status of the digital I/Q input from the optional 'Digital
		Baseband' interface. For details see 'Interface Status Information'. \n
			:return: result: 1 | 2 irrelevant"""
		response = self._core.io.query_str(f'INPut:DIQ:CDEVice?')
		return trim_str_response(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default) -> None:
		"""SCPI: CONFigure[:LTE]:DL[:CC<cc>]:MBSFn:SUBFrame<sf>:STATe \n
		Snippet: driver.applications.k10Xlte.configure.lte.downlink.cc.mbsfn.subframe.state.set(state = False, carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default) \n
		This command turns a subframe into an MBSFN subframe. \n
			:param state: ON | OFF | 1 | 0
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
		"""
		param = Conversions.bool_to_str(state)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		self._core.io.write(f'CONFigure:LTE:DL:CC{carrierComponent_cmd_val}:MBSFn:SUBFrame{subframe_cmd_val}:STATe {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default, subframe=repcap.Subframe.Default) -> bool:
		"""SCPI: CONFigure[:LTE]:DL[:CC<cc>]:MBSFn:SUBFrame<sf>:STATe \n
		Snippet: value: bool = driver.applications.k10Xlte.configure.lte.downlink.cc.mbsfn.subframe.state.get(carrierComponent = repcap.CarrierComponent.Default, subframe = repcap.Subframe.Default) \n
		This command turns a subframe into an MBSFN subframe. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param subframe: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subframe')
			:return: state: ON | OFF | 1 | 0"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		subframe_cmd_val = self._cmd_group.get_repcap_cmd_value(subframe, repcap.Subframe)
		response = self._core.io.query_str(f'CONFigure:LTE:DL:CC{carrierComponent_cmd_val}:MBSFn:SUBFrame{subframe_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TransmissionCls:
	"""Transmission commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("transmission", core, parent)

	def set(self, transmission_type: enums.CestTransmType) -> None:
		"""SCPI: [SENSe]:CESTimation:TRANsmission \n
		Snippet: driver.applications.k17Mcgd.sense.cestimation.transmission.set(transmission_type = enums.CestTransmType.OWAY) \n
		Defines the satellite transmission type. This information is necessary to correctly calculate the Max Clock Offset. \n
			:param transmission_type: OWAY One-Way Transmission TWAY Two-Way Transmission
		"""
		param = Conversions.enum_scalar_to_str(transmission_type, enums.CestTransmType)
		self._core.io.write(f'SENSe:CESTimation:TRANsmission {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.CestTransmType:
		"""SCPI: [SENSe]:CESTimation:TRANsmission \n
		Snippet: value: enums.CestTransmType = driver.applications.k17Mcgd.sense.cestimation.transmission.get() \n
		Defines the satellite transmission type. This information is necessary to correctly calculate the Max Clock Offset. \n
			:return: transmission_type: OWAY One-Way Transmission TWAY Two-Way Transmission"""
		response = self._core.io.query_str(f'SENSe:CESTimation:TRANsmission?')
		return Conversions.str_to_scalar_enum(response, enums.CestTransmType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ShowCls:
	"""Show commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("show", core, parent)

	def set(self, result: enums.SummaryMode) -> None:
		"""SCPI: [SENSe]:NR5G:RSUMmary:SHOW \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.rsummary.show.set(result = enums.SummaryMode.AVERage) \n
		This command selects the way the contents of the result summary are calculated. \n
			:param result: AVERage Shows the average over all analyzed frames. SINGle Shows the result for the frame selected with [SENSe:]NR5G[:CCcc]:FRAMe:SELect. If only one frame has been captured, the results are the same in both cases.
		"""
		param = Conversions.enum_scalar_to_str(result, enums.SummaryMode)
		self._core.io.write(f'SENSe:NR5G:RSUMmary:SHOW {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SummaryMode:
		"""SCPI: [SENSe]:NR5G:RSUMmary:SHOW \n
		Snippet: value: enums.SummaryMode = driver.applications.k14Xnr5G.sense.nr5G.rsummary.show.get() \n
		This command selects the way the contents of the result summary are calculated. \n
			:return: result: AVERage Shows the average over all analyzed frames. SINGle Shows the result for the frame selected with [SENSe:]NR5G[:CCcc]:FRAMe:SELect. If only one frame has been captured, the results are the same in both cases."""
		response = self._core.io.query_str(f'SENSe:NR5G:RSUMmary:SHOW?')
		return Conversions.str_to_scalar_enum(response, enums.SummaryMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def set(self, yaxis: enums.AxisFreqItems, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TRENd:CHIRp:FREQuency:Y \n
		Snippet: driver.applications.k60Transient.calculate.trend.chirp.frequency.y.set(yaxis = enums.AxisFreqItems.AVGFm, window = repcap.Window.Default) \n
		Configures the y-axis of the Parameter Trend result display for chirp frequency parameters. \n
			:param yaxis: AVGFm | AVGNonlinear | BWIDth | CHERror | FREQuency | MAXFm | MAXNonlinear | RMSFm | RMSNonlinear CHERror Chirp state deviation FREQuency Average frequency MAXFm Maximum Frequency Deviation RMSFm RMS Frequency Deviation AVGFm Average Frequency Deviation FMSPoint FM settling point FMSTime FM settling time FMSLength FM settled length BWIDth Bandwidth AVGNonlinear Average frequency non-linearity RMSNonlinear RMS frequency non-linearity MAXNonlinear Peak frequency non-linearity PMSPoint PM settling point PMSTime PM settling time PMSLength PM settled length
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.enum_scalar_to_str(yaxis, enums.AxisFreqItems)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRENd:CHIRp:FREQuency:Y {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StepCls:
	"""Step commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("step", core, parent)

	def set(self, step: float) -> None:
		"""SCPI: CONFigure:PSWeep:Y:STEP \n
		Snippet: driver.applications.k18AmplifierEt.configure.psweep.y.step.set(step = 1.0) \n
		This command defines the stepsize for the second parameter controlled by the parameter sweep. \n
			:param step: numeric value whose unit depends on the parameter type you have selected with method RsFsw.Applications.K18_AmplifierEt.Configure.Psweep.Y.Setting.set: • Hz in case of the center frequency • dB in case of the output level • s in case of the delay between envelope and RF signal • V in case of the envelope bias
		"""
		param = Conversions.decimal_value_to_str(step)
		self._core.io.write(f'CONFigure:PSWeep:Y:STEP {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:PSWeep:Y:STEP \n
		Snippet: value: float = driver.applications.k18AmplifierEt.configure.psweep.y.step.get() \n
		This command defines the stepsize for the second parameter controlled by the parameter sweep. \n
			:return: step: numeric value whose unit depends on the parameter type you have selected with method RsFsw.Applications.K18_AmplifierEt.Configure.Psweep.Y.Setting.set: • Hz in case of the center frequency • dB in case of the output level • s in case of the delay between envelope and RF signal • V in case of the envelope bias"""
		response = self._core.io.query_str(f'CONFigure:PSWeep:Y:STEP?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, statistic_type: enums.StatisticType, window=repcap.Window.Default) -> None:
		"""SCPI: [SENSe]:STATistic<n>:TYPE \n
		Snippet: driver.applications.k60Transient.sense.statistic.typePy.set(statistic_type = enums.StatisticType.ALL, window = repcap.Window.Default) \n
		No command help available \n
			:param statistic_type: SELected | ALL SELected Only the selected hop/chirp from each sweep (capture) is included in the statistical evaluation. ALL All measured hops/chirps from each sweep (capture) are included in the statistical evaluation.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Statistic')
		"""
		param = Conversions.enum_scalar_to_str(statistic_type, enums.StatisticType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'SENSe:STATistic{window_cmd_val}:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.StatisticType:
		"""SCPI: [SENSe]:STATistic<n>:TYPE \n
		Snippet: value: enums.StatisticType = driver.applications.k60Transient.sense.statistic.typePy.get(window = repcap.Window.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Statistic')
			:return: statistic_type: SELected | ALL SELected Only the selected hop/chirp from each sweep (capture) is included in the statistical evaluation. ALL All measured hops/chirps from each sweep (capture) are included in the statistical evaluation."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'SENSe:STATistic{window_cmd_val}:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.StatisticType)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SenseCls:
	"""Sense commands group definition. 214 total commands, 17 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def lte(self):
		"""lte commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_lte'):
			from .Lte import LteCls
			self._lte = LteCls(self._core, self._cmd_group)
		return self._lte

	@property
	def adjust(self):
		"""adjust commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def average(self):
		"""average commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_average'):
			from .Average import AverageCls
			self._average = AverageCls(self._core, self._cmd_group)
		return self._average

	@property
	def bandwidth(self):
		"""bandwidth commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def demod(self):
		"""demod commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_demod'):
			from .Demod import DemodCls
			self._demod = DemodCls(self._core, self._cmd_group)
		return self._demod

	@property
	def detector(self):
		"""detector commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_detector'):
			from .Detector import DetectorCls
			self._detector = DetectorCls(self._core, self._cmd_group)
		return self._detector

	@property
	def espectrum(self):
		"""espectrum commands group. 13 Sub-classes, 0 commands."""
		if not hasattr(self, '_espectrum'):
			from .Espectrum import EspectrumCls
			self._espectrum = EspectrumCls(self._core, self._cmd_group)
		return self._espectrum

	@property
	def frequency(self):
		"""frequency commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def iq(self):
		"""iq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def inputPy(self):
		"""inputPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def msra(self):
		"""msra commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_msra'):
			from .Msra import MsraCls
			self._msra = MsraCls(self._core, self._cmd_group)
		return self._msra

	@property
	def pmeter(self):
		"""pmeter commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_pmeter'):
			from .Pmeter import PmeterCls
			self._pmeter = PmeterCls(self._core, self._cmd_group)
		return self._pmeter

	@property
	def power(self):
		"""power commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def probe(self):
		"""probe commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_probe'):
			from .Probe import ProbeCls
			self._probe = ProbeCls(self._core, self._cmd_group)
		return self._probe

	@property
	def swapIq(self):
		"""swapIq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_swapIq'):
			from .SwapIq import SwapIqCls
			self._swapIq = SwapIqCls(self._core, self._cmd_group)
		return self._swapIq

	@property
	def sweep(self):
		"""sweep commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def sync(self):
		"""sync commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sync'):
			from .Sync import SyncCls
			self._sync = SyncCls(self._core, self._cmd_group)
		return self._sync

	def clone(self) -> 'SenseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SenseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UpperCls:
	"""Upper commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("upper", core, parent)

	def set(self, value: float) -> None:
		"""SCPI: [SENSe]:ADJust:CONFigure:HYSTeresis:UPPer \n
		Snippet: driver.applications.k17Mcgd.sense.adjust.configure.hysteresis.upper.set(value = 1.0) \n
		When the reference level is adjusted automatically using the [SENSe:]ADJust:LEVel command, the internal attenuators and
		the preamplifier are also adjusted. To avoid frequent adaptation due to small changes in the input signal, you can define
		a hysteresis. This setting defines an upper threshold the signal must exceed (compared to the last measurement) before
		the reference level is adapted automatically. \n
			:param value: Range: 0 dB to 200 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(value)
		self._core.io.write(f'SENSe:ADJust:CONFigure:HYSTeresis:UPPer {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADJust:CONFigure:HYSTeresis:UPPer \n
		Snippet: value: float = driver.applications.k17Mcgd.sense.adjust.configure.hysteresis.upper.get() \n
		When the reference level is adjusted automatically using the [SENSe:]ADJust:LEVel command, the internal attenuators and
		the preamplifier are also adjusted. To avoid frequent adaptation due to small changes in the input signal, you can define
		a hysteresis. This setting defines an upper threshold the signal must exceed (compared to the last measurement) before
		the reference level is adapted automatically. \n
			:return: value: No help available"""
		response = self._core.io.query_str(f'SENSe:ADJust:CONFigure:HYSTeresis:UPPer?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nr5GCls:
	"""Nr5G commands group definition. 53 total commands, 17 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nr5G", core, parent)

	@property
	def acPower(self):
		"""acPower commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_acPower'):
			from .AcPower import AcPowerCls
			self._acPower = AcPowerCls(self._core, self._cmd_group)
		return self._acPower

	@property
	def cc(self):
		"""cc commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_cc'):
			from .Cc import CcCls
			self._cc = CcCls(self._core, self._cmd_group)
		return self._cc

	@property
	def ccolor(self):
		"""ccolor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ccolor'):
			from .Ccolor import CcolorCls
			self._ccolor = CcolorCls(self._core, self._cmd_group)
		return self._ccolor

	@property
	def cdrPower(self):
		"""cdrPower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cdrPower'):
			from .CdrPower import CdrPowerCls
			self._cdrPower = CdrPowerCls(self._core, self._cmd_group)
		return self._cdrPower

	@property
	def demod(self):
		"""demod commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_demod'):
			from .Demod import DemodCls
			self._demod = DemodCls(self._core, self._cmd_group)
		return self._demod

	@property
	def emHold(self):
		"""emHold commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_emHold'):
			from .EmHold import EmHoldCls
			self._emHold = EmHoldCls(self._core, self._cmd_group)
		return self._emHold

	@property
	def tdView(self):
		"""tdView commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tdView'):
			from .TdView import TdViewCls
			self._tdView = TdViewCls(self._core, self._cmd_group)
		return self._tdView

	@property
	def efilter(self):
		"""efilter commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_efilter'):
			from .Efilter import EfilterCls
			self._efilter = EfilterCls(self._core, self._cmd_group)
		return self._efilter

	@property
	def fevents(self):
		"""fevents commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fevents'):
			from .Fevents import FeventsCls
			self._fevents = FeventsCls(self._core, self._cmd_group)
		return self._fevents

	@property
	def frame(self):
		"""frame commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_frame'):
			from .Frame import FrameCls
			self._frame = FrameCls(self._core, self._cmd_group)
		return self._frame

	@property
	def iq(self):
		"""iq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def ooPower(self):
		"""ooPower commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ooPower'):
			from .OoPower import OoPowerCls
			self._ooPower = OoPowerCls(self._core, self._cmd_group)
		return self._ooPower

	@property
	def rantenna(self):
		"""rantenna commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rantenna'):
			from .Rantenna import RantennaCls
			self._rantenna = RantennaCls(self._core, self._cmd_group)
		return self._rantenna

	@property
	def rsummary(self):
		"""rsummary commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rsummary'):
			from .Rsummary import RsummaryCls
			self._rsummary = RsummaryCls(self._core, self._cmd_group)
		return self._rsummary

	@property
	def scc(self):
		"""scc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scc'):
			from .Scc import SccCls
			self._scc = SccCls(self._core, self._cmd_group)
		return self._scc

	@property
	def segment(self):
		"""segment commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_segment'):
			from .Segment import SegmentCls
			self._segment = SegmentCls(self._core, self._cmd_group)
		return self._segment

	@property
	def tracking(self):
		"""tracking commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_tracking'):
			from .Tracking import TrackingCls
			self._tracking = TrackingCls(self._core, self._cmd_group)
		return self._tracking

	def clone(self) -> 'Nr5GCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Nr5GCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LedStateCls:
	"""LedState commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ledState", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.LedState:
		"""SCPI: CONFigure:CFReduction:CFDelta:LEDState \n
		Snippet: value: enums.LedState = driver.applications.k18AmplifierEt.configure.cfReduction.cfDelta.ledState.get() \n
		Reads the LED status of the crest factor delta. \n
			:return: state: GREY | RED | GREen"""
		response = self._core.io.query_str(f'CONFigure:CFReduction:CFDelta:LEDState?')
		return Conversions.str_to_scalar_enum(response, enums.LedState)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> enums.LimitCheck:
		"""SCPI: CALCulate<n>:LIMit<li>:BURSt:ALL:RESult \n
		Snippet: value: enums.LimitCheck = driver.applications.k91Wlan.calculate.limit.burst.all.result.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command returns the result of the EVM limit check for all carriers. The limit value is defined by the standard or
		the user (see method RsFsw.Applications.K91_Wlan.Calculate.Limit.Burst.All.set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: limit_check: PASS | FAILed PASS The defined limit for the parameter was not exceeded. FAILED The defined limit for the parameter was exceeded."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:BURSt:ALL:RESult?')
		return Conversions.str_to_scalar_enum(response, enums.LimitCheck)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ShiftCls:
	"""Shift commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("shift", core, parent)

	def set(self, distance: float, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:CONTrol:SHIFt \n
		Snippet: driver.calculate.limit.control.shift.set(distance = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command moves a complete limit line horizontally. Compared to defining an offset, this command actually changes the
		limit line definition points by the value you define. \n
			:param distance: Numeric value. The unit depends on the scale of the x-axis. Unit: HZ
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.decimal_value_to_str(distance)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CONTrol:SHIFt {param}')

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit<li>:CONTrol:SHIFt \n
		Snippet: value: float = driver.calculate.limit.control.shift.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command moves a complete limit line horizontally. Compared to defining an offset, this command actually changes the
		limit line definition points by the value you define. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: distance: Numeric value. The unit depends on the scale of the x-axis. Unit: HZ"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CONTrol:SHIFt?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: enums.LimitState, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<range>:LIMit:STATe \n
		Snippet: driver.applications.k14Xnr5G.sense.espectrum.range.limit.state.set(state = enums.LimitState.ABSolute, subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param state: No help available
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.enum_scalar_to_str(state, enums.LimitState)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit:STATe {param}')

	# noinspection PyTypeChecker
	def get(self, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default) -> enums.LimitState:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<range>:LIMit:STATe \n
		Snippet: value: enums.LimitState = driver.applications.k14Xnr5G.sense.espectrum.range.limit.state.get(subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: state: No help available"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.LimitState)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AverageCls:
	"""Average commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("average", core, parent)

	def get(self, query_range: enums.SelectionRangeB) -> float:
		"""SCPI: FETCh:STABle:P2DB:IN:AVERage \n
		Snippet: value: float = driver.applications.k18AmplifierEt.fetch.stable.p2Db.inputPy.average.get(query_range = enums.SelectionRangeB.ALL) \n
		No command help available \n
			:param query_range: No help available
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(query_range, enums.SelectionRangeB)
		response = self._core.io.query_str(f'FETCh:STABle:P2DB:IN:AVERage? {param}')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InvertedCls:
	"""Inverted commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("inverted", core, parent)

	def set(self, value: float, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:IQ:OSC:SKEW:I:INVerted \n
		Snippet: driver.applications.iqAnalyzer.inputPy.iq.osc.skew.icomponent.inverted.set(value = 1.0, inputIx = repcap.InputIx.Default) \n
		Compensates for skewed values in the negative I path, e.g. due to different input cables. \n
			:param value: Unit: S
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.decimal_value_to_str(value)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:IQ:OSC:SKEW:I:INVerted {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> float:
		"""SCPI: INPut<ip>:IQ:OSC:SKEW:I:INVerted \n
		Snippet: value: float = driver.applications.iqAnalyzer.inputPy.iq.osc.skew.icomponent.inverted.get(inputIx = repcap.InputIx.Default) \n
		Compensates for skewed values in the negative I path, e.g. due to different input cables. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: value: Unit: S"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IQ:OSC:SKEW:I:INVerted?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CenterCls:
	"""Center commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("center", core, parent)

	def set(self, frequency: float, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SBLock<sb>:FREQuency:CENTer \n
		Snippet: driver.sense.power.achannel.sblock.frequency.center.set(frequency = 1.0, subBlock = repcap.SubBlock.Default) \n
		This command defines the center of the specified MSR sub block. Note that the position of the sub block also affects the
		position of the adjacent gap (CACLR) channels. This command is for MSR signals only (see method RsFsw.Calculate.Marker.
		Function.Power.preset) . For details on MSR signals see 'Measurement on multi-standard radio (MSR) signals'. \n
			:param frequency: absolute frequency in Hz Unit: Hz
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sblock')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:POWer:ACHannel:SBLock{subBlock_cmd_val}:FREQuency:CENTer {param}')

	def get(self, subBlock=repcap.SubBlock.Default) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:SBLock<sb>:FREQuency:CENTer \n
		Snippet: value: float = driver.sense.power.achannel.sblock.frequency.center.get(subBlock = repcap.SubBlock.Default) \n
		This command defines the center of the specified MSR sub block. Note that the position of the sub block also affects the
		position of the adjacent gap (CACLR) channels. This command is for MSR signals only (see method RsFsw.Calculate.Marker.
		Function.Power.preset) . For details on MSR signals see 'Measurement on multi-standard radio (MSR) signals'. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sblock')
			:return: frequency: absolute frequency in Hz Unit: Hz"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SBLock{subBlock_cmd_val}:FREQuency:CENTer?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SenseCls:
	"""Sense commands group definition. 69 total commands, 11 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def adjust(self):
		"""adjust commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def correction(self):
		"""correction commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_correction'):
			from .Correction import CorrectionCls
			self._correction = CorrectionCls(self._core, self._cmd_group)
		return self._correction

	@property
	def frequency(self):
		"""frequency commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def iq(self):
		"""iq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def swapIq(self):
		"""swapIq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_swapIq'):
			from .SwapIq import SwapIqCls
			self._swapIq = SwapIqCls(self._core, self._cmd_group)
		return self._swapIq

	@property
	def sweep(self):
		"""sweep commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def tracking(self):
		"""tracking commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_tracking'):
			from .Tracking import TrackingCls
			self._tracking = TrackingCls(self._core, self._cmd_group)
		return self._tracking

	@property
	def pmeter(self):
		"""pmeter commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_pmeter'):
			from .Pmeter import PmeterCls
			self._pmeter = PmeterCls(self._core, self._cmd_group)
		return self._pmeter

	@property
	def burst(self):
		"""burst commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_burst'):
			from .Burst import BurstCls
			self._burst = BurstCls(self._core, self._cmd_group)
		return self._burst

	@property
	def demod(self):
		"""demod commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_demod'):
			from .Demod import DemodCls
			self._demod = DemodCls(self._core, self._cmd_group)
		return self._demod

	@property
	def mixer(self):
		"""mixer commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_mixer'):
			from .Mixer import MixerCls
			self._mixer = MixerCls(self._core, self._cmd_group)
		return self._mixer

	def clone(self) -> 'SenseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SenseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:LIST:POWer:RESult \n
		Snippet: value: float = driver.sense.listPy.power.result.get() \n
		This command queries the results of the list evaluation. This command may be used to obtain measurement results in an
		asynchronous way, using the service request mechanism for synchronization to the end of the measurement. If there are no
		results, the command returns an error. \n
			:return: power_level: Power level for each frequency included in the measurement. The command returns up to 3 power levels for each frequency, depending on the number of evaluation modes you have turned on with [SENSe:]LIST:POWer:SET. The result is a list of floating point values separated by commas. The unit depends on method RsFsw.Applications.K91_Wlan.Calculate.Unit.Power.set."""
		response = self._core.io.query_str(f'SENSe:LIST:POWer:RESult?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def set(self, result: float, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:Y \n
		Snippet: driver.applications.k14Xnr5G.calculate.marker.y.set(result = 1.0, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the position of a marker on the y-axis. In result displays with a third aspect (for example 'EVM vs
		Symbol x Carrier') , you can also use the command to define the position of the marker on the y-axis. If necessary, the
		command activates the marker first. To get a valid result, you have to perform a complete measurement with
		synchronization to the end of the measurement before reading out the result. This is only possible for single measurement
		mode. See also method RsFsw.Applications.K10x_Lte.Initiate.Continuous.set. \n
			:param result: numeric value Result at the marker position. The type of value and its unit depend on the selected result display.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.decimal_value_to_str(result)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:Y {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:Y \n
		Snippet: value: float = driver.applications.k14Xnr5G.calculate.marker.y.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the position of a marker on the y-axis. In result displays with a third aspect (for example 'EVM vs
		Symbol x Carrier') , you can also use the command to define the position of the marker on the y-axis. If necessary, the
		command activates the marker first. To get a valid result, you have to perform a complete measurement with
		synchronization to the end of the measurement before reading out the result. This is only possible for single measurement
		mode. See also method RsFsw.Applications.K10x_Lte.Initiate.Continuous.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: numeric value Result at the marker position. The type of value and its unit depend on the selected result display."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:Y?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SizeCls:
	"""Size commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("size", core, parent)

	def get(self, fileList=repcap.FileList.Default) -> int:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:FLISt<fli>:SIZE \n
		Snippet: value: int = driver.sense.correction.fresponse.user.flist.size.get(fileList = repcap.FileList.Default) \n
		Queries the number of entries in the list of .fres files for the current configuration. \n
			:param fileList: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Flist')
			:return: size: integer Range: 1 to 15"""
		fileList_cmd_val = self._cmd_group.get_repcap_cmd_value(fileList, repcap.FileList)
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:USER:FLISt{fileList_cmd_val}:SIZE?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReadCls:
	"""Read commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("read", core, parent)

	def get(self) -> str:
		"""SCPI: CONFigure:GENerator:RELay:READ \n
		Snippet: value: str = driver.applications.k18AmplifierEt.configure.generator.relay.read.get() \n
		Provides functionality to read the answer if the command that was sent to the signal generator using method RsFsw.
		Configure.Generator.Relay.Write.set contained a '?'. \n
			:return: response: No help available"""
		response = self._core.io.query_str_with_opc(f'CONFigure:GENerator:RELay:READ?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PservoingCls:
	"""Pservoing commands group definition. 8 total commands, 5 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pservoing", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def target(self):
		"""target commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_target'):
			from .Target import TargetCls
			self._target = TargetCls(self._core, self._cmd_group)
		return self._target

	@property
	def max(self):
		"""max commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_max'):
			from .Max import MaxCls
			self._max = MaxCls(self._core, self._cmd_group)
		return self._max

	@property
	def glc(self):
		"""glc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_glc'):
			from .Glc import GlcCls
			self._glc = GlcCls(self._core, self._cmd_group)
		return self._glc

	@property
	def inputPy(self):
		"""inputPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	def start(self) -> None:
		"""SCPI: [SENSe]:PSERvoing:STARt \n
		Snippet: driver.applications.k18AmplifierEt.sense.pservoing.start() \n
		Starts the power servoing sequence. \n
		"""
		self._core.io.write(f'SENSe:PSERvoing:STARt')

	def start_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:PSERvoing:STARt \n
		Snippet: driver.applications.k18AmplifierEt.sense.pservoing.start_with_opc() \n
		Starts the power servoing sequence. \n
		Same as start, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:PSERvoing:STARt', opc_timeout_ms)

	def clone(self) -> 'PservoingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PservoingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CstepCls:
	"""Cstep commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cstep", core, parent)

	def set(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:CSTep \n
		Snippet: driver.calculate.marker.function.cstep.set(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command matches the center frequency step size to the current marker frequency. The command turns delta markers into
		normal markers. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:CSTep')

	def set_with_opc(self, window=repcap.Window.Default, marker=repcap.Marker.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:CSTep \n
		Snippet: driver.calculate.marker.function.cstep.set_with_opc(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command matches the center frequency step size to the current marker frequency. The command turns delta markers into
		normal markers. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:CSTep', opc_timeout_ms)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaxCls:
	"""Max commands group definition. 3 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("max", core, parent)

	@property
	def limit(self):
		"""limit commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import LimitCls
			self._limit = LimitCls(self._core, self._cmd_group)
		return self._limit

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TABLe:POWer:MAX \n
		Snippet: driver.applications.k6Pulse.calculate.table.power.max.set(state = False, window = repcap.Window.Default) \n
		If enabled, the maximum Tx power is included in the result tables. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TABLe:POWer:MAX {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:TABLe:POWer:MAX \n
		Snippet: value: bool = driver.applications.k6Pulse.calculate.table.power.max.get(window = repcap.Window.Default) \n
		If enabled, the maximum Tx power is included in the result tables. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | OFF | 1 | 0"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TABLe:POWer:MAX?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'MaxCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MaxCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SubwindowCls:
	"""Subwindow commands group definition. 23 total commands, 8 Subgroups, 0 group commands
	Repeated Capability: SubWindow, default value after init: SubWindow.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("subwindow", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_subWindow_get', 'repcap_subWindow_set', repcap.SubWindow.Nr1)

	def repcap_subWindow_set(self, subWindow: repcap.SubWindow) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to SubWindow.Default
		Default value after init: SubWindow.Nr1"""
		self._cmd_group.set_repcap_enum_value(subWindow)

	def repcap_subWindow_get(self) -> repcap.SubWindow:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def ccNumber(self):
		"""ccNumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ccNumber'):
			from .CcNumber import CcNumberCls
			self._ccNumber = CcNumberCls(self._core, self._cmd_group)
		return self._ccNumber

	@property
	def coupling(self):
		"""coupling commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coupling'):
			from .Coupling import CouplingCls
			self._coupling = CouplingCls(self._core, self._cmd_group)
		return self._coupling

	@property
	def fnumber(self):
		"""fnumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fnumber'):
			from .Fnumber import FnumberCls
			self._fnumber = FnumberCls(self._core, self._cmd_group)
		return self._fnumber

	@property
	def isnumber(self):
		"""isnumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_isnumber'):
			from .Isnumber import IsnumberCls
			self._isnumber = IsnumberCls(self._core, self._cmd_group)
		return self._isnumber

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def size(self):
		"""size commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_size'):
			from .Size import SizeCls
			self._size = SizeCls(self._core, self._cmd_group)
		return self._size

	@property
	def trace(self):
		"""trace commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def zoom(self):
		"""zoom commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_zoom'):
			from .Zoom import ZoomCls
			self._zoom = ZoomCls(self._core, self._cmd_group)
		return self._zoom

	def clone(self) -> 'SubwindowCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SubwindowCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.Utilities import trim_str_response
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RelativeCls:
	"""Relative commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("relative", core, parent)

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> str:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>[:CACLr]:RESult:RELative \n
		Snippet: value: str = driver.applications.k14Xnr5G.calculate.limit.acPower.gap.caclr.result.relative.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		This command queries the relative limit check results for the gap channels (MC ACLR measurements) .
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select relative limit check mode evaluation mode ACLR: method RsFsw.Calculate.Limit.AcPower.Pmode.set. Combined measurements: [SENSe:]NR5G:ACPower:ALPMode \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: limit_check: Returns two values, one for the upper and one for the lower adjacent channel. PASSED Limit check has passed. FAILED Limit check has failed."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:CACLr:RESult:RELative?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WriteCls:
	"""Write commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("write", core, parent)

	def set(self) -> None:
		"""SCPI: CONFigure:REFSignal:GOS:WRITe \n
		Snippet: driver.applications.k18AmplifierEt.configure.refSignal.gos.write.set() \n
		This command internally generates the reference signal based on the signal characteristics that you have defined.
		The waveform file that has been created is loaded into the DSP of the R&S FSW-K18 and is additionally transferred into
		the ARB of the signal generator. Make sure to synchronize with *OPC? or *WAI to make sure that the command was
		successfully applied on the generator before sending the next command. \n
		"""
		self._core.io.write(f'CONFigure:REFSignal:GOS:WRITe')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CONFigure:REFSignal:GOS:WRITe \n
		Snippet: driver.applications.k18AmplifierEt.configure.refSignal.gos.write.set_with_opc() \n
		This command internally generates the reference signal based on the signal characteristics that you have defined.
		The waveform file that has been created is loaded into the DSP of the R&S FSW-K18 and is additionally transferred into
		the ARB of the signal generator. Make sure to synchronize with *OPC? or *WAI to make sure that the command was
		successfully applied on the generator before sending the next command. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CONFigure:REFSignal:GOS:WRITe', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: enums.LimitState, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:LIMit<li>:STATe \n
		Snippet: driver.sense.espectrum.range.limit.state.set(state = enums.LimitState.ABSolute, subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default, limitIx = repcap.LimitIx.Default) \n
		This command selects the limit check mode for all SEM ranges (<range> is irrelevant) . \n
			:param state: ABSolute | RELative | AND | OR ABSolute Checks only the absolute limits defined. RELative Checks only the relative limits. Relative limits are defined as relative to the measured power in the reference range. AND Combines the absolute and relative limit. The limit check fails when both limits are violated. OR Combines the absolute and relative limit. The limit check fails when one of the limits is violated.
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.enum_scalar_to_str(state, enums.LimitState)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit{limitIx_cmd_val}:STATe {param}')

	# noinspection PyTypeChecker
	def get(self, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, limitIx=repcap.LimitIx.Default) -> enums.LimitState:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:LIMit<li>:STATe \n
		Snippet: value: enums.LimitState = driver.sense.espectrum.range.limit.state.get(subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default, limitIx = repcap.LimitIx.Default) \n
		This command selects the limit check mode for all SEM ranges (<range> is irrelevant) . \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: state: ABSolute | RELative | AND | OR ABSolute Checks only the absolute limits defined. RELative Checks only the relative limits. Relative limits are defined as relative to the measured power in the reference range. AND Combines the absolute and relative limit. The limit check fails when both limits are violated. OR Combines the absolute and relative limit. The limit check fails when one of the limits is violated."""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit{limitIx_cmd_val}:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.LimitState)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, method: enums.MimoAnalyzeMethod) -> None:
		"""SCPI: CONFigure:WLAN:MIMO:CAPTure:TYPE \n
		Snippet: driver.applications.k91Wlan.configure.wlan.mimo.capture.typePy.set(method = enums.MimoAnalyzeMethod.MANual) \n
		Specifies the method used to analyze MIMO signals. \n
			:param method: SIMultaneous | OSP | MANual SIMultaneous Simultaneous normal MIMO operation OSP Sequential using open switch platform MANual Sequential using manual operation
		"""
		param = Conversions.enum_scalar_to_str(method, enums.MimoAnalyzeMethod)
		self._core.io.write(f'CONFigure:WLAN:MIMO:CAPTure:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.MimoAnalyzeMethod:
		"""SCPI: CONFigure:WLAN:MIMO:CAPTure:TYPE \n
		Snippet: value: enums.MimoAnalyzeMethod = driver.applications.k91Wlan.configure.wlan.mimo.capture.typePy.get() \n
		Specifies the method used to analyze MIMO signals. \n
			:return: method: SIMultaneous | OSP | MANual SIMultaneous Simultaneous normal MIMO operation OSP Sequential using open switch platform MANual Sequential using manual operation"""
		response = self._core.io.query_str(f'CONFigure:WLAN:MIMO:CAPTure:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.MimoAnalyzeMethod)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SplitterCls:
	"""Splitter commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("splitter", core, parent)

	def set(self, index_1: float, index_2: float, position: float) -> None:
		"""SCPI: LAYout:SPLitter \n
		Snippet: driver.applications.k91Wlan.layout.splitter.set(index_1 = 1.0, index_2 = 1.0, position = 1.0) \n
		This command changes the position of a splitter and thus controls the size of the windows on each side of the splitter.
		Compared to the method RsFsw.Applications.K17_Mcgd.Display.Window.Size.set command, the method RsFsw.Applications.
		K17_Mcgd.Layout.Splitter.set changes the size of all windows to either side of the splitter permanently, it does not just
		maximize a single window temporarily. Note that windows must have a certain minimum size. If the position you define
		conflicts with the minimum size of any of the affected windows, the command does not work, but does not return an error. \n
			:param index_1: The index of one window the splitter controls.
			:param index_2: The index of a window on the other side of the splitter.
			:param position: New vertical or horizontal position of the splitter as a fraction of the screen area (without channel and status bar and softkey menu) . The point of origin (x = 0, y = 0) is in the lower left corner of the screen. The end point (x = 100, y = 100) is in the upper right corner of the screen. (See Figure 'SmartGrid coordinates for remote control of the splitters'.) The direction in which the splitter is moved depends on the screen layout. If the windows are positioned horizontally, the splitter also moves horizontally. If the windows are positioned vertically, the splitter also moves vertically. Range: 0 to 100
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('index_1', index_1, DataType.Float), ArgSingle('index_2', index_2, DataType.Float), ArgSingle('position', position, DataType.Float))
		self._core.io.write_with_opc(f'LAYout:SPLitter {param}'.rstrip())

	# noinspection PyTypeChecker
	class SplitterStruct(StructBase):
		"""Response structure. Fields: \n
			- Index_1: float: The index of one window the splitter controls.
			- Index_2: float: The index of a window on the other side of the splitter.
			- Position: float: New vertical or horizontal position of the splitter as a fraction of the screen area (without channel and status bar and softkey menu) . The point of origin (x = 0, y = 0) is in the lower left corner of the screen. The end point (x = 100, y = 100) is in the upper right corner of the screen. (See Figure 'SmartGrid coordinates for remote control of the splitters'.) The direction in which the splitter is moved depends on the screen layout. If the windows are positioned horizontally, the splitter also moves horizontally. If the windows are positioned vertically, the splitter also moves vertically. Range: 0 to 100"""
		__meta_args_list = [
			ArgStruct.scalar_float('Index_1'),
			ArgStruct.scalar_float('Index_2'),
			ArgStruct.scalar_float('Position')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Index_1: float = None
			self.Index_2: float = None
			self.Position: float = None

	def get(self) -> SplitterStruct:
		"""SCPI: LAYout:SPLitter \n
		Snippet: value: SplitterStruct = driver.applications.k91Wlan.layout.splitter.get() \n
		This command changes the position of a splitter and thus controls the size of the windows on each side of the splitter.
		Compared to the method RsFsw.Applications.K17_Mcgd.Display.Window.Size.set command, the method RsFsw.Applications.
		K17_Mcgd.Layout.Splitter.set changes the size of all windows to either side of the splitter permanently, it does not just
		maximize a single window temporarily. Note that windows must have a certain minimum size. If the position you define
		conflicts with the minimum size of any of the affected windows, the command does not work, but does not return an error. \n
			:return: structure: for return value, see the help for SplitterStruct structure arguments."""
		return self._core.io.query_struct_with_opc(f'LAYout:SPLitter?', self.__class__.SplitterStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, ref_channel: enums.RefChannel) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:REFerence:TXCHannel:AUTO \n
		Snippet: driver.sense.power.achannel.reference.txChannel.auto.set(ref_channel = enums.RefChannel.LHIGhest) \n
		This command selects the reference channel for relative measurements. You need at least one channel for the command to
		work. \n
			:param ref_channel: MINimum | MAXimum | LHIGhest MINimum Transmission channel with the lowest power MAXimum Transmission channel with the highest power LHIGhest Lowest transmission channel for lower adjacent channels and highest transmission channel for upper adjacent channels
		"""
		param = Conversions.enum_scalar_to_str(ref_channel, enums.RefChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:REFerence:TXCHannel:AUTO {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>[:STATe] \n
		Snippet: driver.applications.k70Vsa.calculate.deltaMarker.state.set(state = False, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command turns delta markers on and off. If necessary, the command activates the delta marker first. No suffix at
		DELTamarker turns on delta marker 1. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:STATe {param}')

	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> bool:
		"""SCPI: CALCulate<n>:DELTamarker<m>[:STATe] \n
		Snippet: value: bool = driver.applications.k70Vsa.calculate.deltaMarker.state.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command turns delta markers on and off. If necessary, the command activates the delta marker first. No suffix at
		DELTamarker turns on delta marker 1. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)
